"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rx = require("rxjs");
var child_process_1 = require("child_process");
var ExecFileEndpoint = /** @class */ (function () {
    function ExecFileEndpoint(file, args, options) {
        var _this = this;
        this.file = file;
        this.args = args;
        this.options = options;
        this.input = rx.Observable.create(function (observer) {
            var errorStack = [];
            _this.subProcess = child_process_1.execFile(_this.file, _this.args, _this.options);
            _this.subProcess.stdout.on('data', function (data) {
                observer.next(String(data));
            });
            _this.subProcess.stdout.on('error', function (error) {
                observer.error(error);
            });
            _this.subProcess.stderr.on('data', function (err) {
                errorStack.push(err);
            });
            _this.subProcess.on('close', function (status, signal) {
                if (status !== 0) {
                    observer.error({
                        status: status,
                        signal: signal,
                        errors: errorStack
                    });
                }
                else {
                    observer.complete();
                }
            });
            _this.subProcess.on('error', function (_data) {
                errorStack.push(_data);
            });
        });
        this.output = new rx.Subject();
        this.output.subscribe(function (a) {
            _this.subProcess.stdin.write(a);
        }, function (e) { }, function () {
            _this.subProcess.stdin.end();
        });
    }
    ExecFileEndpoint.command = function (file, args, options) {
        if (args === void 0) { args = []; }
        if (options === void 0) { options = {}; }
        return new ExecFileEndpoint(file, args, options);
    };
    ExecFileEndpoint.prototype.kill = function () {
        this.subProcess.kill();
    };
    return ExecFileEndpoint;
}());
exports.ExecFileEndpoint = ExecFileEndpoint;
exports.default = ExecFileEndpoint;
//# sourceMappingURL=execFile-endpoint.js.map