"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var execFile_endpoint_1 = require("../src/execFile-endpoint");
var chai_1 = require("chai");
var path = require("path");
var flatten = function (arr) {
    return (_a = Array.prototype).concat.apply(_a, arr);
    var _a;
};
function normalizeArray(arr) {
    var arrWithoutWS = arr.map(function (el) { return String(el).split('\n'); });
    return flatten(arrWithoutWS)
        .filter(function (el) { return el !== ''; })
        .map(function (n) { return parseInt(n, 10); });
}
function readAssert(rxep, done) {
    var checkArray = [];
    rxep.input.subscribe(function (data) {
        checkArray.push(data);
    }, function (error) {
        chai_1.assert.fail('ERROR should not received', error);
    }, function () {
        chai_1.assert.deepEqual(normalizeArray(checkArray), [1, 2, 3, 4, 5, 6]);
        done();
    });
}
describe('Endpoint execFile', function () {
    it('can error', function (done) {
        var eep = execFile_endpoint_1.default.command('/wtf/wtf');
        eep.input.subscribe(function (data) {
            chai_1.assert.fail('never called');
        }, function (err) {
            chai_1.assert.equal(err.errors[0].code, 'ENOENT');
            // node 6 return -2
            // node 0.10 return -1
            chai_1.assert.isTrue(err.status < 0);
            done();
        }, function () {
            chai_1.assert.fail('never called');
        });
    });
    it('can exit code', function (done) {
        var eep = execFile_endpoint_1.default.command(process.execPath, ['-e', 'process.exit(47)']);
        eep.input.subscribe(function (data) {
            chai_1.assert.fail('never called');
        }, function (err) {
            chai_1.assert.equal(err.status, 47);
            done();
        }, function () {
            chai_1.assert.fail('never called');
        });
    });
    it('can receive if spawned.', function (done) {
        var eep = execFile_endpoint_1.default.command(process.execPath, ['-e', '[1, 2, 3, 4, 5, 6].forEach(function(el) { console.log(el); })']);
        readAssert(eep, done);
    });
    it('can span a echo server', function (done) {
        var eep = execFile_endpoint_1.default.command(process.execPath, [path.join('dist', 'test', 'helper', 'process-echo.js')]);
        readAssert(eep, done);
        [1, 2, 3, 4, 5, 6].forEach(function (el) {
            eep.output.next(el + "\n");
        });
        eep.output.complete();
    });
});
//# sourceMappingURL=execFile-endpoint-test.js.map